copepod_shortform_names: Retrieve a named vector of column names for copepod shortform

View source: R/io.R

copepod_shortform_namesR Documentation

Retrieve a named vector of column names for copepod shortform

Description

Retrieve a named vector of column names for copepod shortform

Usage

copepod_shortform_names(strip = TRUE)

Arguments

strip

logical, if TRUE strip the names off

Value

named vector of column names


BigelowLab/copepoda documentation built on March 29, 2022, 10:07 p.m.