| list_data | R Documentation |
Retrieve the path to one or more copepod datasets
list_data(
copepid = "us-04201",
form = c("short", "full")[1],
path = get_data_path()
)
copepid |
character, the copepid of the data set ala "us-04201" |
form |
character, one of "short" or "full" |
path |
character the root path |
character vector of filenames
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.