read_copepod_shortform: Read a short-form data file

View source: R/io.R

read_copepod_shortformR Documentation

Read a short-form data file

Description

Read a short-form data file

Usage

read_copepod_shortform(
  filename,
  skip = 17,
  col_names = copepod_shortform_names(),
  col_types = copepod_shortform_types()
)

Arguments

filename

the name of the file

skip

the number of header lines to skip

col_names

a vector of columns names including a trailing 'dummy' which is dropped

col_types

a vector or compact character string used to declare input column types

Value

tibble


BigelowLab/copepoda documentation built on March 29, 2022, 10:07 p.m.