| read_copepod_shortform | R Documentation |
Read a short-form data file
read_copepod_shortform( filename, skip = 17, col_names = copepod_shortform_names(), col_types = copepod_shortform_types() )
filename |
the name of the file |
skip |
the number of header lines to skip |
col_names |
a vector of columns names including a trailing 'dummy' which is dropped |
col_types |
a vector or compact character string used to declare input column types |
tibble
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.